@@ -30,7 +30,7 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group()
-@click.version_option("76.1.4",package_name="alacorder")
+@click.version_option("76.1.7", package_name="alacorder")
 def cli():
     """
     ALACORDER beta 76
@@ -59,6 +59,7 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
 
     ogtable = table
     archive = False
+    show_options_menu = False
 
     log = not log 
 
@@ -88,6 +89,8 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
         click.echo(outputs.ECHO)
     if not outputs.GOOD:
         raise Exception("Invalid output path!")
+    if outputs.OUTPUT_EXT != ".xlsx" and outputs.OUTPUT_EXT != ".xls" and outputs.OUTPUT_EXT != ".dta" and outputs.OUTPUT_EXT != ".json" and outputs.OUTPUT_EXT != ".csv" and outputs.OUTPUT_EXT != ".zip" and outputs.OUTPUT_EXT != ".pkl":
+        raise Exception("Bad format!")
 
     # prompt overwrite
     if outputs.EXISTING_FILE and not overwrite:
@@ -122,7 +125,7 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
                 table = "filing"
             else:
                 cal.echo_yellow("Invalid table selection!", echo=True)
-
+    '''
     change = False
 
     if show_options_menu and not no_prompt:
@@ -162,25 +165,8 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
                     table = "filing"
                 else:
                     cal.echo_yellow("Invalid table selection!", echo=True)
-    
-    if table != ogtable:
-        # inputs - configure and log
-        inputs = cal.setinputs(input_path)
-        if debug:
-            click.echo(inputs)
-        if log:
-            click.echo(inputs.ECHO)
-        if not inputs.GOOD:
-            raise Exception("Invalid input path!")
+    '''
 
-        # outputs - configure and log
-        outputs = cal.setoutputs(output_path,archive=False)
-        if debug:
-            click.echo(outputs)
-        if log:
-            click.echo(outputs.ECHO)
-        if not outputs.GOOD:
-            raise Exception("Invalid output path!")
 
     # finalize config
     cf = cal.set(inputs, outputs, count=count, table=table, overwrite=overwrite, log=log, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
@@ -221,12 +207,13 @@ def table(input_path, output_path, count, table, overwrite, log, no_write, no_pr
 @click.version_option(package_name='alacorder', prog_name='ALACORDER', message='%(prog)s beta %(version)s')
 def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no_batch, no_prompt, debug, compress):
 
+    # show_options_menu = False
     table = ""
     archive = True
 
-    log = not log 
+    log = not log
 
-    show_options_menu = False
+    # show_options_menu = False
 
     # suppress tracebacks unless debug
     if not debug:
@@ -253,6 +240,10 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
     if not outputs.GOOD:
         raise Exception("Invalid output path!")
 
+    if outputs.OUTPUT_EXT != ".pkl" and outputs.OUTPUT_EXT != ".xz" and outputs.OUTPUT_EXT != ".zip" and outputs.OUTPUT_EXT != ".json" and outputs.OUTPUT_EXT != ".csv" and outputs.OUTPUT_EXT != ".zip" and outputs.OUTPUT_EXT != ".pkl":
+        raise Exception("Bad format!")
+
+
     # prompt overwrite
     if outputs.EXISTING_FILE and not overwrite:
         if no_prompt:
@@ -264,9 +255,8 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
                 raise Exception("Existing file at output path!")
 
 
-    # prompt options
-    change = False
 
+    '''
     if show_options_menu and not no_prompt:
         if not click.confirm("Continue with current settings?"):
             change = True
@@ -291,16 +281,7 @@ def archive(input_path, output_path, count, overwrite, dedupe, log, no_write, no
                 no_batch = click.prompt("Should Alacorder process all cases in one batch? [y/N]", type=bool)
             elif p == "compress" or p == "--compress" or p == "-zip" or p == "zip" or p == "-z" or p == "z":
                 compress = click.prompt("Should Alacorder compress exports? [y/N]", type=bool)
-
-
-        # outputs - configure and log
-        outputs = cal.setoutputs(output_path,archive=True)
-        if debug:
-            click.echo(outputs)
-        if log:
-            click.echo(outputs.ECHO)
-        if not outputs.GOOD:
-            raise Exception("Invalid output path!")
+        '''
 
     # finalize config
     cf = cal.set(inputs, outputs, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt, no_batch=no_batch, debug=debug, compress=compress)
@@ -348,7 +329,7 @@ def readPartySearchQuery(path, qmax=0, qskip=0, speed=1, no_log=False):
 @click.option("--output-path", "-out", "path", required=True, prompt="PDF download path", type=click.Path(), help="Desired PDF output directory")
 @click.option("--customer-id", "-c","cID", required=True, prompt="Alacourt Customer ID", help="Customer ID on Alacourt.com")
 @click.option("--user-id", "-u","uID", required=True, prompt="Alacourt User ID", help="User ID on Alacourt.com")
-@click.option("--password", "-p","pwd", required=True, prompt="Alacourt Password", help="Password on Alacourt.com")
+@click.option("--password", "-p","pwd", required=True, prompt="Alacourt Password", help="Password on Alacourt.com", hide_input=True)
 @click.option("--archive-path", "-a", required=False, type=click.Path(), help="Create archive after directory export")
 @click.option("--max", "-max","qmax", required=False, type=int, help="Maximum queries to conduct on Alacourt.com",default=0)
 @click.option("--skip", "-skip","qskip", required=False, type=int, help="Skip entries at top of query file",default=0)
@@ -364,7 +345,6 @@ def scrape(listpath, path, cID, uID, pwd, archive_path, qmax, qskip, speed, no_l
     """
     query = readPartySearchQuery(listpath, qmax, qskip, no_log)
 
-
     options = webdriver.ChromeOptions()
     options.add_experimental_option('prefs', {
         "download.default_directory": path, #Change default directory for downloads
@@ -382,7 +362,7 @@ def scrape(listpath, path, cID, uID, pwd, archive_path, qmax, qskip, speed, no_l
 
     if not no_log:
         cal.echo_green("Authentication successful. Beginning search...")
-
+    
     ii = 0
     i = 0
     if not no_log:
@@ -396,6 +376,8 @@ def scrape(listpath, path, cID, uID, pwd, archive_path, qmax, qskip, speed, no_l
                 time.sleep(1.5/speed)
     if no_log:
             for n in query.index:
+                if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
+                    login(driver, cID, uID, pwd, speed)
                 results = party_search(driver, name=query.NAME[n], party_type=query.PARTY_TYPE[n], ssn=query.SSN[n], dob=query.DOB[n], county=query.COUNTY[n], division=query.DIVISION[n], case_year=query.CASE_YEAR[n], no_records=query.NO_RECORDS[n], filed_before=query.FILED_BEFORE[n], filed_after=query.FILED_AFTER[n], speed=speed, no_log=no_log)
                 for url in results:
                     ii += 1
